@@ -79,11 +79,11 @@ void KrBriefViewToolTip::maybeTip( const TQPoint &pos )
 }
 
 
-KrBriefView::KrBriefView( TQHeader * headerIn, TQWidget *parent, bool &left, KConfig *cfg, const char *name ):
-	KIconView(parent, name), KrView( cfg ), header( headerIn ), _currDragItem( 0 ),
+KrBriefView::KrBriefView( TQHeader * headerIn, TQWidget *parent, bool &left, TDEConfig *cfg, const char *name ):
+	TDEIconView(parent, name), KrView( cfg ), header( headerIn ), _currDragItem( 0 ),
             currentlyRenamedItem( 0 ), pressedItem( 0 ), mouseEvent( 0 ) {
 	setWidget( this );
-	_nameInKConfig = TQString( "KrBriefView" ) + TQString( ( left ? "Left" : "Right" ) );
+	_nameInTDEConfig = TQString( "KrBriefView" ) + TQString( ( left ? "Left" : "Right" ) );
 	krConfig->setGroup("Private");
 	if (krConfig->readBoolEntry("Enable Input Method", true))
 		setInputMethodEnabled(true);
@@ -93,12 +93,12 @@ KrBriefView::KrBriefView( TQHeader * headerIn, TQWidget *parent, bool &left, KCo
 void KrBriefView::setup() {
    lastSwushPosition = 0;
       
-   // use the {} so that KConfigGroupSaver will work correctly!
-   KConfigGroupSaver grpSvr( _config, "Look&Feel" );
+   // use the {} so that TDEConfigGroupSaver will work correctly!
+   TDEConfigGroupSaver grpSvr( _config, "Look&Feel" );
    setFont( _config->readFontEntry( "Filelist Font", _FilelistFont ) );
    // decide on single click/double click selection
    if ( _config->readBoolEntry( "Single Click Selects", _SingleClickSelects ) &&
-           KGlobalSettings::singleClick() ) {
+           TDEGlobalSettings::singleClick() ) {
       connect( this, TQT_SIGNAL( executed( TQIconViewItem* ) ), this, TQT_SLOT( slotExecuted( TQIconViewItem* ) ) );
    } else {
       connect( this, TQT_SIGNAL( clicked( TQIconViewItem* ) ), this, TQT_SLOT( slotClicked( TQIconViewItem* ) ) );
@@ -118,7 +118,7 @@ void KrBriefView::setup() {
    connect( &KrColorCache::getColorCache(), TQT_SIGNAL( colorsRefreshed() ), this, TQT_SLOT( refreshColors() ) );
 
    // add whatever columns are needed to the listview
-   krConfig->setGroup( nameInKConfig() );
+   krConfig->setGroup( nameInTDEConfig() );
    
    // determine basic settings for the view
    setAcceptDrops( true );
@@ -175,7 +175,7 @@ void KrBriefView::resizeEvent ( TQResizeEvent * resEvent )
    if( currentItem() )
      visible = viewportRect.contains( currentItem()->rect() );
 
-   KIconView::resizeEvent( resEvent );
+   TDEIconView::resizeEvent( resEvent );
    redrawColumns();
 
    if( visible && currentItem() )
@@ -300,7 +300,7 @@ void KrBriefView::addItems( vfs *v, bool addUpDir ) {
 
    if ( !currentItem )
       currentItem = firstItem();
-   KIconView::setCurrentItem( currentItem );
+   TDEIconView::setCurrentItem( currentItem );
    ensureItemVisible( currentItem );
 
    op()->emitItemDescription( statusText );
@@ -322,7 +322,7 @@ TQString KrBriefView::getCurrentItem() const {
 void KrBriefView::setCurrentItem( const TQString& name ) {
    KrBriefViewItem * it = dynamic_cast<KrBriefViewItem*>(_dict[ name ]);
    if ( it )
-      KIconView::setCurrentItem( it );
+      TDEIconView::setCurrentItem( it );
 }
 
 void KrBriefView::clear() {
@@ -332,7 +332,7 @@ void KrBriefView::clear() {
    }
 
    op()->emitSelectionChanged(); /* to avoid rename crash at refresh */
-   KIconView::clear();
+   TDEIconView::clear();
    KrView::clear();
 }
 
@@ -341,7 +341,7 @@ void KrBriefView::slotClicked( TQIconViewItem *item ) {
 
    if ( !modifierPressed ) {
       if ( singleClicked && !renameTimer.isActive() ) {
-         KConfig * config = KGlobal::config();
+         TDEConfig * config = TDEGlobal::config();
          config->setGroup( "KDE" );
          int doubleClickInterval = config->readNumEntry( "DoubleClickInterval", 400 );
 
@@ -378,7 +378,7 @@ void KrBriefView::prepareForActive() {
 void KrBriefView::prepareForPassive() {
    KrView::prepareForPassive();
    CANCEL_TWO_CLICK_RENAME;
-   KConfigGroupSaver grpSvr( _config, "Look&Feel" );
+   TDEConfigGroupSaver grpSvr( _config, "Look&Feel" );
    if ( _config->readBoolEntry( "New Style Quicksearch", _NewStyleQuicksearch ) ) {
       if ( MAIN_VIEW ) {
          if ( ACTIVE_PANEL ) {
@@ -405,7 +405,7 @@ void KrBriefView::handleQuickSearchEvent( TQKeyEvent * e ) {
          case Key_Insert:
          {
             TQKeyEvent ev = TQKeyEvent( TQKeyEvent::KeyPress, Key_Space, 0, 0 );
-            KIconView::keyPressEvent( & ev );
+            TDEIconView::keyPressEvent( & ev );
             ev = TQKeyEvent( TQKeyEvent::KeyPress, Key_Down, 0, 0 );
             keyPressEvent( & ev );
             break;
@@ -537,7 +537,7 @@ void KrBriefView::contentsMousePressEvent( TQMouseEvent * e ) {
    }
 
    // stop quick search in case a mouse click occured
-   KConfigGroupSaver grpSvr( _config, "Look&Feel" );
+   TDEConfigGroupSaver grpSvr( _config, "Look&Feel" );
    if ( _config->readBoolEntry( "New Style Quicksearch", _NewStyleQuicksearch ) ) {
       if ( MAIN_VIEW ) {
          if ( ACTIVE_PANEL ) {
@@ -594,7 +594,7 @@ void KrBriefView::contentsMousePressEvent( TQMouseEvent * e ) {
      if( newCurrent )                 // save the name of the file
        name = static_cast<KrBriefViewItem*>( newCurrent ) ->name();
 
-     KIconView::contentsMousePressEvent( e );
+     TDEIconView::contentsMousePressEvent( e );
 
      if( name.isEmpty() || _dict.find( name ) == 0 ) // is the file still valid?
        newCurrent = 0;                // if not, don't do any crash...
@@ -634,7 +634,7 @@ void KrBriefView::contentsMouseReleaseEvent( TQMouseEvent * e ) {
   
   e = transformMouseEvent( e );
   
-  KIconView::contentsMouseReleaseEvent( e );
+  TDEIconView::contentsMouseReleaseEvent( e );
    
   if( pressedItem ) {
     TQPoint vp = contentsToViewport( e->pos() );
@@ -708,13 +708,13 @@ void KrBriefView::contentsMouseMoveEvent ( TQMouseEvent * e ) {
            emit onViewport();
       }
       else
-         KIconView::contentsMouseMoveEvent( e );
+         TDEIconView::contentsMouseMoveEvent( e );
 }
 
 void KrBriefView::contentsMouseDoubleClickEvent ( TQMouseEvent * e )
 {
    e = transformMouseEvent ( e );
-   KIconView::contentsMouseDoubleClickEvent( e );
+   TDEIconView::contentsMouseDoubleClickEvent( e );
 }
 
 void KrBriefView::handleContextMenu( TQIconViewItem * it, const TQPoint & pos ) {
@@ -743,7 +743,7 @@ void KrBriefView::showContextMenu()
 }
 
 KrViewItem *KrBriefView::getKrViewItemAt( const TQPoint & vp ) {
-   return dynamic_cast<KrViewItem*>( KIconView::findItem( vp ) );
+   return dynamic_cast<KrViewItem*>( TDEIconView::findItem( vp ) );
 }
 
 bool KrBriefView::acceptDrag( TQDropEvent* ) const {
@@ -754,7 +754,7 @@ void KrBriefView::contentsDropEvent( TQDropEvent * e ) {
    _currDragItem = 0;
    op()->emitGotDrop(e);
    e->ignore();
-   KIconView::contentsDropEvent( e );                   
+   TDEIconView::contentsDropEvent( e );                   
 }
 
 void KrBriefView::contentsDragMoveEvent( TQDragMoveEvent * e ) {
@@ -764,7 +764,7 @@ void KrBriefView::contentsDragMoveEvent( TQDragMoveEvent * e ) {
    if( _currDragItem && !_currDragItem->VF->vfile_isDir() )
      _currDragItem = 0;
    
-   KIconView::contentsDragMoveEvent( e );
+   TDEIconView::contentsDragMoveEvent( e );
 
    if( _currDragItem != oldDragItem )
    {
@@ -780,7 +780,7 @@ void KrBriefView::contentsDragLeaveEvent ( TQDragLeaveEvent *e )
    KrViewItem *oldDragItem = _currDragItem;
 
    _currDragItem = 0;
-   KIconView::contentsDragLeaveEvent( e );
+   TDEIconView::contentsDragLeaveEvent( e );
 
    if( oldDragItem )
      dynamic_cast<KrBriefViewItem *>( oldDragItem )->repaint();
@@ -792,9 +792,9 @@ void KrBriefView::imStartEvent(TQIMEvent* e)
     ACTIVE_PANEL->quickSearch->myIMStartEvent( e );
     return ;
   }else {
-    KConfigGroupSaver grpSvr( _config, "Look&Feel" );
+    TDEConfigGroupSaver grpSvr( _config, "Look&Feel" );
     if ( !_config->readBoolEntry( "New Style Quicksearch", _NewStyleQuicksearch ) )
-      KIconView::imStartEvent( e );
+      TDEIconView::imStartEvent( e );
     else {
 							// first, show the quicksearch if its hidden
       if ( ACTIVE_PANEL->quickSearch->isHidden() ) {
@@ -850,7 +850,7 @@ void KrBriefView::keyPressEvent( TQKeyEvent * e ) {
 					TQIconView::setCurrentItem( i );
 					TQIconView::ensureItemVisible( i );
 				}
-         } else KIconView::keyPressEvent(e);
+         } else TDEIconView::keyPressEvent(e);
          break;
          case Key_Down :
          if ( e->state() == ControlButton || e->state() == ( ControlButton | ShiftButton ) ) { // let the panel handle it - jump to command line
@@ -862,7 +862,7 @@ void KrBriefView::keyPressEvent( TQKeyEvent * e ) {
             if ( e->state() == ShiftButton ) setSelected( i, !i->isSelected(), true );
             i = i->nextItem();
          if ( i ) {TQIconView::setCurrentItem( i ); TQIconView::ensureItemVisible( i ); }
-         } else KIconView::keyPressEvent(e);
+         } else TDEIconView::keyPressEvent(e);
          break;
          case Key_Next:  if (!KrSelectionMode::getSelectionHandler()->useTQTSelection()){
             TQIconViewItem * i = currentItem(), *j;
@@ -872,7 +872,7 @@ void KrBriefView::keyPressEvent( TQKeyEvent * e ) {
             for ( int page = visibleHeight() / r.height() - 1; page > 0 && ( j = i->nextItem() ); --page )
                i = j;
             if ( i ) {TQIconView::setCurrentItem( i ); TQIconView::ensureItemVisible( i ); }
-         } else KIconView::keyPressEvent(e);
+         } else TDEIconView::keyPressEvent(e);
          break;
          case Key_Prior:  if (!KrSelectionMode::getSelectionHandler()->useTQTSelection()){
             TQIconViewItem * i = currentItem(), *j;
@@ -882,13 +882,13 @@ void KrBriefView::keyPressEvent( TQKeyEvent * e ) {
             for ( int page = visibleHeight() / r.height() - 1; page > 0 && ( j = i->prevItem() ); --page )
                i = j;
             if ( i ) {TQIconView::setCurrentItem( i ); TQIconView::ensureItemVisible( i ); }
-         } else KIconView::keyPressEvent(e);
+         } else TDEIconView::keyPressEvent(e);
          break;
          case Key_Home:  if (!KrSelectionMode::getSelectionHandler()->useTQTSelection()){
             if ( e->state() & ShiftButton )  /* Shift+Home */
             {
                clearSelection();
-               KIconView::keyPressEvent( e );
+               TDEIconView::keyPressEvent( e );
                op()->emitSelectionChanged();
                arrangeItemsInGrid();
                break;
@@ -896,13 +896,13 @@ void KrBriefView::keyPressEvent( TQKeyEvent * e ) {
                TQIconViewItem * i = firstItem();
                if ( i ) {TQIconView::setCurrentItem( i ); TQIconView::ensureItemVisible( i ); }
             }
-         } else KIconView::keyPressEvent(e);
+         } else TDEIconView::keyPressEvent(e);
          break;
          case Key_End:  if (!KrSelectionMode::getSelectionHandler()->useTQTSelection()){
             if ( e->state() & ShiftButton )  /* Shift+End */
             {
                clearSelection();
-               KIconView::keyPressEvent( e );
+               TDEIconView::keyPressEvent( e );
                op()->emitSelectionChanged();
                arrangeItemsInGrid();
                break;
@@ -915,7 +915,7 @@ void KrBriefView::keyPressEvent( TQKeyEvent * e ) {
             if ( i ) {TQIconView::setCurrentItem( i ); TQIconView::ensureItemVisible( i ); }
                break;
             }
-         } else KIconView::keyPressEvent(e);
+         } else TDEIconView::keyPressEvent(e);
          break;
          case Key_Enter :
          case Key_Return : {
@@ -977,7 +977,7 @@ void KrBriefView::keyPressEvent( TQKeyEvent * e ) {
               TQIconView::setCurrentItem( newCurrent );
               TQIconView::ensureItemVisible( newCurrent );
             }
-         } else KIconView::keyPressEvent(e);
+         } else TDEIconView::keyPressEvent(e);
          break;
          case Key_Backspace :                         // Terminal Emulator bugfix
          if ( e->state() == ControlButton || e->state() == ShiftButton ) { // let the panel handle it
@@ -1026,7 +1026,7 @@ void KrBriefView::keyPressEvent( TQKeyEvent * e ) {
               TQIconView::setCurrentItem( newCurrent );
               TQIconView::ensureItemVisible( newCurrent );
             }
-         } else KIconView::keyPressEvent(e);
+         } else TDEIconView::keyPressEvent(e);
          break;
 
          case Key_Delete :                   // kill file
@@ -1079,7 +1079,7 @@ void KrBriefView::keyPressEvent( TQKeyEvent * e ) {
          }
          case Key_A :                 // mark all
          if ( e->state() == ControlButton ) {
-            KIconView::keyPressEvent( e );
+            TDEIconView::keyPressEvent( e );
             updateView();
             break;
          }
@@ -1098,9 +1098,9 @@ void KrBriefView::keyPressEvent( TQKeyEvent * e ) {
             //if ( _config->readBoolEntry( "Do Quicksearch", _DoQuicksearch ) ) {
                // are we using krusader's classic quicksearch, or wincmd style?
                {
-						KConfigGroupSaver grpSvr( _config, "Look&Feel" );
+						TDEConfigGroupSaver grpSvr( _config, "Look&Feel" );
 						if ( !_config->readBoolEntry( "New Style Quicksearch", _NewStyleQuicksearch ) )
-							KIconView::keyPressEvent( e );
+							TDEIconView::keyPressEvent( e );
 						else {
 							// first, show the quicksearch if its hidden
 							if ( ACTIVE_PANEL->quickSearch->isHidden() ) {
@@ -1125,7 +1125,7 @@ void KrBriefView::keyPressEvent( TQKeyEvent * e ) {
                ACTIVE_PANEL->quickSearch->clear();
                krDirUp->setEnabled( true );
             }
-            KIconView::keyPressEvent( e );
+            TDEIconView::keyPressEvent( e );
          }
    }
    // emit the new item description
@@ -1155,7 +1155,7 @@ void KrBriefView::renameCurrentItem() {
    rename( static_cast<TQIconViewItem*>( it ) );
    // if applicable, select only the name without extension
 /* TODO:
-   KConfigGroupSaver svr(krConfig,"Look&Feel");
+   TDEConfigGroupSaver svr(krConfig,"Look&Feel");
    if (!krConfig->readBoolEntry("Rename Selects Extension", true)) {
      if (it->hasExtension() && !it->VF->vfile_isDir() ) 
        renameLineEdit()->setSelection(0, it->name().findRev(it->extension())-1);
@@ -1181,7 +1181,7 @@ void KrBriefView::quickSearch( const TQString & str, int direction ) {
    KrViewItem * item = getCurrentKrViewItem();
    if (!item)
       return;
-   KConfigGroupSaver grpSvr( _config, "Look&Feel" );
+   TDEConfigGroupSaver grpSvr( _config, "Look&Feel" );
    bool caseSensitive = _config->readBoolEntry( "Case Sensitive Quicksearch", _CaseSensitiveQuicksearch );
    if ( !direction ) {
       if ( caseSensitive ? item->name().startsWith( str ) : item->name().lower().startsWith( str.lower() ) )
@@ -1237,7 +1237,7 @@ void KrBriefView::refreshColors() {
       setPaletteBackgroundColor( cg.background() );
    } else {
       // KDE default is choosen: set back the background color
-      setPaletteBackgroundColor( KGlobalSettings::baseColor() );
+      setPaletteBackgroundColor( TDEGlobalSettings::baseColor() );
    }
    slotUpdate();
 }
@@ -1260,7 +1260,7 @@ bool KrBriefView::event( TQEvent *e ) {
          op()->emitNeedFocus();
       setFocus();
    }
-   return KIconView::event( e );
+   return TDEIconView::event( e );
 }
 
 
@@ -1270,7 +1270,7 @@ bool KrBriefView::eventFilter( TQObject * watched, TQEvent * e )
   {
     if( e->type() == TQEvent::Hide || e->type() == TQEvent::Show )
     {
-      bool res = KIconView::eventFilter( watched, e );
+      bool res = TDEIconView::eventFilter( watched, e );
       arrangeItemsInGrid();
       return res;
     }
@@ -1284,7 +1284,7 @@ bool KrBriefView::eventFilter( TQObject * watched, TQEvent * e )
     }
     return FALSE;
   }
-  return KIconView::eventFilter( watched, e );
+  return TDEIconView::eventFilter( watched, e );
 }
 
 void KrBriefView::makeItemVisible( const KrViewItem *item ) {
@@ -1303,7 +1303,7 @@ void KrBriefView::initProperties() {
 	_properties = new KrBriefViewProperties;
 	_properties->filter = KrViewProperties::All;
 	_properties->filterMask = KRQuery( "*" );
-	KConfigGroupSaver grpSvr( _config, "Look&Feel" );
+	TDEConfigGroupSaver grpSvr( _config, "Look&Feel" );
 	_properties->displayIcons = _config->readBoolEntry( "With Icons", _WithIcons );
 	bool dirsByNameAlways = _config->readBoolEntry("Always sort dirs by name", false);
 	_properties->sortMode = static_cast<KrViewProperties::SortSpec>( KrViewProperties::Name |
@@ -1335,7 +1335,7 @@ void KrBriefView::initProperties() {
 	}
 	_properties->atomicExtensions = atomicExtensions;
 	
-	_config->setGroup( nameInKConfig() );
+	_config->setGroup( nameInTDEConfig() );
 	PROPS->numberOfColumns = _config->readNumEntry( "Number Of Brief Columns", _NumberOfBriefColumns );
 	if( PROPS->numberOfColumns < 1 )
 		PROPS->numberOfColumns = 1;
@@ -1345,7 +1345,7 @@ void KrBriefView::initProperties() {
 
 void KrBriefView::setColumnNr()
 {
-  KPopupMenu popup( this );
+  TDEPopupMenu popup( this );
   popup.insertTitle( i18n("Columns"));
   
   int COL_ID = 14700;
@@ -1358,7 +1358,7 @@ void KrBriefView::setColumnNr()
   
   int result=popup.exec(TQCursor::pos());
 
-  krConfig->setGroup( nameInKConfig() );
+  krConfig->setGroup( nameInTDEConfig() );
   
   if( result > COL_ID && result <= COL_ID + MAX_COLS )
   {
